@@ -13,7 +13,6 @@
 #![deny(clippy::cargo_common_metadata)]
 #![deny(clippy::cast_lossless)]
 #![deny(clippy::checked_conversions)]
-#![warn(clippy::clone_on_ref_ptr)]
 #![warn(clippy::cognitive_complexity)]
 #![deny(clippy::debug_assert_with_mut_call)]
 #![deny(clippy::exhaustive_enums)]
@@ -526,6 +525,14 @@ pub enum ErrorKind {
     #[display(fmt = "no exit available for path")]
     NoExit,
 
+    /// An operation failed because of _possible_ clock skew.
+    ///
+    /// The broken clock may be ours, or it may belong to another party on the
+    /// network. It's also possible that somebody else is lying about the time,
+    /// caching documents for far too long, or something like that.
+    #[display(fmt = "possible clock skew detected")]
+    ClockSkew,
+
     /// Internal error (bug) in Arti.
     ///
     /// A supposedly impossible problem has arisen.  This indicates a bug in
@@ -533,6 +540,16 @@ pub enum ErrorKind {
     /// our [bug tracker](https://gitlab.torproject.org/tpo/core/arti/-/issues).
     #[display(fmt = "internal error (bug)")]
     Internal,
+
+    /// Unclassified error
+    ///
+    /// Some other error occurred, which does not fit into any of the other kinds.
+    ///
+    /// This kind is provided for use by external code
+    /// hooking into or replacing parts of Arti.
+    /// It is never returned by the code in Arti (`arti-*` and `tor-*` crates).
+    #[display(fmt = "unclassified error")]
+    Other,
 }
 
 /// Errors that can be categorized as belonging to an [`ErrorKind`]
